@@ -1,12 +1,12 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/installer/RCS/manifest.tcl,v $
-# $Date: 1999/09/14 09:08:38 $
-# $Revision: 1.18.1.286 $
+# $Date: 2000/06/07 09:20:57 $
+# $Revision: 1.18.1.308 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
 # ----------------------------------------------------------------------
-# Copyright 1998 The University of Newcastle upon Tyne (see COPYRIGHT)
+# Copyright 2000 The University of Newcastle upon Tyne (see COPYRIGHT)
 # ======================================================================
 #
 array set Manifest [list  \
@@ -71,6 +71,8 @@ array set Manifest [list  \
     [file join installer file80.tcl]		{} \
     [file join installer file81.tcl]		{} \
     [file join installer file82.tcl]		{} \
+    [file join installer file83.tcl]		{} \
+    [file join installer file84.tcl]		{} \
     [file join installer support.tcl]		{} \
     [file join installer mac.tcl]		{} \
     [file join installer macfile.tcl]		{} \
@@ -157,6 +159,8 @@ array set Manifest [list  \
     [file join lib tcl80.tcl]			{copy} \
     [file join lib tcl81.tcl]			{copy} \
     [file join lib tcl82.tcl]			{copy} \
+    [file join lib tcl83.tcl]			{copy} \
+    [file join lib tcl84.tcl]			{copy} \
     [file join lib Unix.tcl]			{copy} \
     [file join lib Windows.tcl]			{copy} \
     [file join lib debug.tcl]			{copy} \
@@ -178,138 +182,147 @@ array set Manifest [list  \
     [file join plugins Sed crypt.c]		{prog7} \
     [file join samples zircon.ad]		{ncopy} \
     [file join samples Preferences]		{} \
-    [file join samples Netspaces 3Dnet]		{} \
-    [file join samples Netspaces AMnet]		{} \
-    [file join samples Netspaces Afternet]	{} \
-    [file join samples Netspaces Airnet]	{} \
-    [file join samples Netspaces Alternativenet]       {} \
-    [file join samples Netspaces AngelEyes]	{} \
-    [file join samples Netspaces Asianet]	{} \
-    [file join samples Netspaces Asixnet]       {} \
-    [file join samples Netspaces Astrolink]	{} \
-    [file join samples Netspaces Asylumnet]	{} \
-    [file join samples Netspaces Austnet]       {} \
-    [file join samples Netspaces Badnet]	{} \
-    [file join samples Netspaces BeyondIRC]	{} \
-    [file join samples Netspaces Blazednet]	{} \
-    [file join samples Netspaces Brasirc]       {} \
-    [file join samples Netspaces Brasirc-com]	{} \
-    [file join samples Netspaces Brasnet]       {} \
-    [file join samples Netspaces CCnet]		{} \
-    [file join samples Netspaces CMDnet]	{} \
-    [file join samples Netspaces CNN]		{} \
-    [file join samples Netspaces Castlenet]	{} \
-    [file join samples Netspaces Chatcircuit]	{} \
-    [file join samples Netspaces Chatlink]	{} \
-    [file join samples Netspaces Chatnet]       {} \
-    [file join samples Netspaces Circanet]	{} \
-    [file join samples Netspaces Cynet]		{} \
-    [file join samples Netspaces DALnet]	{} \
-    [file join samples Netspaces DC-net]	{} \
-    [file join samples Netspaces Darkernet]	{} \
-    [file join samples Netspaces Darkfire]	{} \
-    [file join samples Netspaces Darknet]       {} \
-    [file join samples Netspaces Darktree]	{} \
-    [file join samples Netspaces Darkzone]	{} \
-    [file join samples Netspaces Deepspace]	{} \
-    [file join samples Netspaces Different]	{} \
-    [file join samples Netspaces Dobbernet]	{} \
-    [file join samples Netspaces DreamMyst]	{} \
-    [file join samples Netspaces Dreamnet]	{} \
-    [file join samples Netspaces DuDinet]	{} \
-    [file join samples Netspaces Duh-net]       {} \
-    [file join samples Netspaces Dynastynet]	{} \
-    [file join samples Netspaces EDUchat]       {} \
-    [file join samples Netspaces EFnet]		{} \
-    [file join samples Netspaces EICN]		{} \
-    [file join samples Netspaces Escapenet]	{} \
-    [file join samples Netspaces Esprit]	{} \
-    [file join samples Netspaces Etherlands]	{} \
-    [file join samples Netspaces FDFnet]	{} \
-    [file join samples Netspaces FEFnet]	{} \
-    [file join samples Netspaces Firestar]	{} \
-    [file join samples Netspaces Forestnet]	{} \
-    [file join samples Netspaces FoxChat]       {} \
-    [file join samples Netspaces Galaxynet]	{} \
-    [file join samples Netspaces Gamesnet]	{} \
-    [file join samples Netspaces Gammaforce]	{} \
-    [file join samples Netspaces Gammanet]	{} \
-    [file join samples Netspaces GlobalIRC]	{} \
-    [file join samples Netspaces Grnet]		{} \
-    [file join samples Netspaces IRC-Chat]	{} \
-    [file join samples Netspaces IRC-Hispanonet]	{} \
-    [file join samples Netspaces IRC-Hispanoorg]	{} \
-    [file join samples Netspaces IRCLink]	{} \
-    [file join samples Netspaces IRCnet]	{} \
-    [file join samples Netspaces Kewl.org]	{} \
-    [file join samples Netspaces Kidsworld]	{} \
-    [file join samples Netspaces Knightnet]	{} \
-    [file join samples Netspaces Krushnet]	{} \
-    [file join samples Netspaces Lagnet]	{} \
-    [file join samples Netspaces Littlenet]	{} \
-    [file join samples Netspaces Lunatics]	{} \
-    [file join samples Netspaces MagicStar]	{} \
-    [file join samples Netspaces MegaIRC]       {} \
-    [file join samples Netspaces Mellorien]	{} \
-    [file join samples Netspaces Millenia]	{} \
-    [file join samples Netspaces Moonet]	{} \
-    [file join samples Netspaces Mystical]	{} \
-    [file join samples Netspaces NDRSnet]       {} \
-    [file join samples Netspaces Netlink]       {} \
-    [file join samples Netspaces Netlink-irc]	{} \
-    [file join samples Netspaces Newnet]	{} \
-    [file join samples Netspaces Nightstar]	{} \
-    [file join samples Netspaces Nocnet]	{} \
-    [file join samples Netspaces Novernet]	{} \
-    [file join samples Netspaces Optimus.Org]	{} \
-    [file join samples Netspaces Othernet]	{} \
-    [file join samples Netspaces Otherside]	{} \
-    [file join samples Netspaces OzOrg]		{} \
-    [file join samples Netspaces PTnet]		{} \
-    [file join samples Netspaces Phantomnet]	{} \
-    [file join samples Netspaces Phishynet]	{} \
-    [file join samples Netspaces Phrozen]       {} \
-    [file join samples Netspaces Pseudonet]	{} \
-    [file join samples Netspaces Qualitynet]	{} \
-    [file join samples Netspaces RODnet]	{} \
-    [file join samples Netspaces Red-Latina]	{} \
-    [file join samples Netspaces RedLatina]	{} \
-    [file join samples Netspaces RedeBrasil]	{} \
-    [file join samples Netspaces RedeSul]	{} \
-    [file join samples Netspaces Relicnet]	{} \
-    [file join samples Netspaces Sandnet]       {} \
-    [file join samples Netspaces Sandnet-org]	{} \
-    [file join samples Netspaces SaturnChat]	{} \
-    [file join samples Netspaces ShadowFire]	{} \
-    [file join samples Netspaces Singaporenet]	{} \
-    [file join samples Netspaces Sorcerynet]	{} \
-    [file join samples Netspaces Spidernet]	{} \
-    [file join samples Netspaces StarChat]	{} \
-    [file join samples Netspaces StarFusion]	{} \
-    [file join samples Netspaces StarLink]	{} \
-    [file join samples Netspaces StarLinkIRC]	{} \
-    [file join samples Netspaces Superchat]	{} \
-    [file join samples Netspaces Sysopnet]	{} \
-    [file join samples Netspaces Teenzone]	{} \
-    [file join samples Netspaces TerraX]	{} \
-    [file join samples Netspaces Tr-net]	{} \
-    [file join samples Netspaces TrIrcnet]	{} \
-    [file join samples Netspaces UnderZ]	{} \
-    [file join samples Netspaces Undernet]	{} \
-    [file join samples Netspaces Undienet]	{} \
-    [file join samples Netspaces UnionLatina]	{} \
-    [file join samples Netspaces UnixFreak]	{} \
-    [file join samples Netspaces Valhall]	{} \
-    [file join samples Netspaces Vitamina]	{} \
-    [file join samples Netspaces WIFLnet]	{} \
-    [file join samples Netspaces Warpednet]	{} \
-    [file join samples Netspaces Webnet]	{} \
-    [file join samples Netspaces WonKnet]	{} \
-    [file join samples Netspaces WorldIRC]	{} \
-    [file join samples Netspaces XWorld]	{} \
-    [file join samples Netspaces Xnet]		{} \
-    [file join samples Netspaces ZAnet]		{} \
-    [file join samples Netspaces ZUHnet]	{} \
+    [file join samples Netspaces 3Dnet]		{}\
+    [file join samples Netspaces Acestar]	{}\
+    [file join samples Netspaces Afternet]	{}\
+    [file join samples Netspaces Airnet-irc]	{}\
+    [file join samples Netspaces ArabChat]	{}\
+    [file join samples Netspaces Asixnet]	{}\
+    [file join samples Netspaces AstroLink]	{}\
+    [file join samples Netspaces Asylumnet]	{}\
+    [file join samples Netspaces Austnet]	{}\
+    [file join samples Netspaces AwesomeChat]	{}\
+    [file join samples Netspaces Badnet]	{}\
+    [file join samples Netspaces Beyondirc]	{}\
+    [file join samples Netspaces Bigpond]	{}\
+    [file join samples Netspaces Blabbernet]	{}\
+    [file join samples Netspaces Blazed]	{}\
+    [file join samples Netspaces Bohemians]	{}\
+    [file join samples Netspaces Brasirc]	{}\
+    [file join samples Netspaces Brasirc-com]	{}\
+    [file join samples Netspaces Brasnet]	{}\
+    [file join samples Netspaces CCnet]		{}\
+    [file join samples Netspaces CNN]		{}\
+    [file join samples Netspaces Castlenet]	{}\
+    [file join samples Netspaces Chat-net]	{}\
+    [file join samples Netspaces ChatArea]	{}\
+    [file join samples Netspaces ChatCircuit]	{}\
+    [file join samples Netspaces ChatIRC]	{}\
+    [file join samples Netspaces ChatPR]	{}\
+    [file join samples Netspaces ChatX]		{}\
+    [file join samples Netspaces Chatlink]	{}\
+    [file join samples Netspaces Chatnet]	{}\
+    [file join samples Netspaces Chatpinoy]	{}\
+    [file join samples Netspaces Chatroom]	{}\
+    [file join samples Netspaces Circanet]	{}\
+    [file join samples Netspaces Cyberchat-irc]	{}\
+    [file join samples Netspaces Cynet]		{}\
+    [file join samples Netspaces DALnet]	{}\
+    [file join samples Netspaces DS2]		{}\
+    [file join samples Netspaces DarkMyst]	{}\
+    [file join samples Netspaces Darkernet]	{}\
+    [file join samples Netspaces Darkfire]	{}\
+    [file join samples Netspaces Different]	{}\
+    [file join samples Netspaces Dobbernet]	{}\
+    [file join samples Netspaces Dreamnet]	{}\
+    [file join samples Netspaces Duhnet]	{}\
+    [file join samples Netspaces Dynastynet]	{}\
+    [file join samples Netspaces EFnet]		{}\
+    [file join samples Netspaces EliteOrbit]	{}\
+    [file join samples Netspaces Esprit]	{}\
+    [file join samples Netspaces ExodusIRC]		{}\
+    [file join samples Netspaces FDFnet]		{}\
+    [file join samples Netspaces FEFnet]		{}\
+    [file join samples Netspaces Forestnet]		{}\
+    [file join samples Netspaces GRnet]		{}\
+    [file join samples Netspaces GalaxyNet]		{}\
+    [file join samples Netspaces Gamesnet]		{}\
+    [file join samples Netspaces Gammaforce]		{}\
+    [file join samples Netspaces Global-irc]		{}\
+    [file join samples Netspaces IRC-Chat]		{}\
+    [file join samples Netspaces IRC-Hispano]		{}\
+    [file join samples Netspaces IRCLink]		{}\
+    [file join samples Netspaces IRChat]		{}\
+    [file join samples Netspaces IRCnet]		{}\
+    [file join samples Netspaces Indocafe]		{}\
+    [file join samples Netspaces Infinity]		{}\
+    [file join samples Netspaces KewlOrg]		{}\
+    [file join samples Netspaces KidsWorld]		{}\
+    [file join samples Netspaces Knightnet]		{}\
+    [file join samples Netspaces Kreynet]		{}\
+    [file join samples Netspaces Krushnet]		{}\
+    [file join samples Netspaces Lagnet]		{}\
+    [file join samples Netspaces Librenet]		{}\
+    [file join samples Netspaces MagicStar]		{}\
+    [file join samples Netspaces Mellorien]		{}\
+    [file join samples Netspaces Microsoft]		{}\
+    [file join samples Netspaces Millenia]		{}\
+    [file join samples Netspaces Moonet]		{}\
+    [file join samples Netspaces MultiChat]		{}\
+    [file join samples Netspaces Mysteria]		{}\
+    [file join samples Netspaces Mystical]		{}\
+    [file join samples Netspaces NDRSnet]		{}\
+    [file join samples Netspaces Netlink-irc]		{}\
+    [file join samples Netspaces Nevernet]		{}\
+    [file join samples Netspaces Newnet]		{}\
+    [file join samples Netspaces NightStar]		{}\
+    [file join samples Netspaces Novernet]		{}\
+    [file join samples Netspaces Obsessed]		{}\
+    [file join samples Netspaces OtherSide]		{}\
+    [file join samples Netspaces Othernet]		{}\
+    [file join samples Netspaces OzChat]		{}\
+    [file join samples Netspaces OzOrg]		{}\
+    [file join samples Netspaces PTlink]		{}\
+    [file join samples Netspaces PTnet]		{}\
+    [file join samples Netspaces PhaZeNet]		{}\
+    [file join samples Netspaces Phishynet]		{}\
+    [file join samples Netspaces PowerChat]		{}\
+    [file join samples Netspaces Pseudonet]		{}\
+    [file join samples Netspaces QChat]		{}\
+    [file join samples Netspaces QuakeNet]		{}\
+    [file join samples Netspaces Red-Latina]		{}\
+    [file join samples Netspaces RedeBrasil]		{}\
+    [file join samples Netspaces RedeSul]		{}\
+    [file join samples Netspaces Redfutura]		{}\
+    [file join samples Netspaces Relicnet]		{}\
+    [file join samples Netspaces Risanet]		{}\
+    [file join samples Netspaces Rusnet]		{}\
+    [file join samples Netspaces SamShark]		{}\
+    [file join samples Netspaces SandnetOrg]		{}\
+    [file join samples Netspaces SexNet]		{}\
+    [file join samples Netspaces ShadowFire]		{}\
+    [file join samples Netspaces Slashnet]		{}\
+    [file join samples Netspaces SolarXTReme]		{}\
+    [file join samples Netspaces Sorcery]		{}\
+    [file join samples Netspaces Spynet]		{}\
+    [file join samples Netspaces StarChat]		{}\
+    [file join samples Netspaces StarlinkOrg]		{}\
+    [file join samples Netspaces Superchat]		{}\
+    [file join samples Netspaces SurgeNet]		{}\
+    [file join samples Netspaces Sysopnet]		{}\
+    [file join samples Netspaces TR-net]		{}\
+    [file join samples Netspaces TRcom]		{}\
+    [file join samples Netspaces Thunderirc]		{}\
+    [file join samples Netspaces UIP]		{}\
+    [file join samples Netspaces UnderZ]		{}\
+    [file join samples Netspaces Undernet]		{}\
+    [file join samples Netspaces Undienet]		{}\
+    [file join samples Netspaces UnionLatina]		{}\
+    [file join samples Netspaces Unitedchat]		{}\
+    [file join samples Netspaces Vitamina]		{}\
+    [file join samples Netspaces Warpednet]		{}\
+    [file join samples Netspaces Webnet]		{}\
+    [file join samples Netspaces Wonknet]		{}\
+    [file join samples Netspaces Worldirc]		{}\
+    [file join samples Netspaces XWorld]		{}\
+    [file join samples Netspaces Xnet]		{}\
+    [file join samples Netspaces ZAnetNet]		{}\
+    [file join samples Netspaces ZAnetOrg]		{}\
+    [file join samples Netspaces ZUHnet]		{}\
+    [file join samples Netspaces Zurna]		{}\
+    [file join samples Netspaces sandnetNet]		{}\
+    [file join samples Netspaces shadowWorld]		{}\
+    [file join samples Netspaces starlink-irc]		{}\
     scripts					{dmake} \
     sounds					{dmake} \
     [file join util findMeta]			{} \
@@ -318,5 +331,5 @@ array set Manifest [list  \
 set Index "lib [file join plugins Dcc] [file join plugins Sed]"
 #
 set Version 1.18
-set Patchlevel 224
+set Patchlevel 244
 
