@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Channel.tcl,v $
-# $Date: 1999/08/16 13:44:40 $
-# $Revision: 1.18.1.189 $
+# $Date: 2000/03/21 15:53:09 $
+# $Revision: 1.18.1.192 $
 #
 #
 package provide zircon 1.18
@@ -228,7 +228,13 @@ proc channel_addText {this tag text} {
 	    if {[[$this net] noPopup]} {
 		[$this wid] noPopUp $this
 	    } {
-		[$this wid] expose $this
+		switch nil [$this wid] {
+		    if {[$this isa Info]} {
+		        exposeFrame [MainControl] [$this net]
+		    }
+		} default {
+		    [$this wid] expose $this
+		}
 		handleOn [$this net] POPUP [list [$this lname]]
 	    }
 	}
@@ -631,21 +637,19 @@ proc makeCTopic {this net w chan rchan idx cdx look} {
     frame $w.topic -borderwidth 0
     grid columnconfigure $w.topic 1 -weight 1
     menubutton $w.topic.label -text [trans topic] -relief raised \
-      -state disabled
-    $w.topic.label conf -menu $w.topic.label.menu
+      -menu $w.topic.label.menu
     set om [menu $w.topic.label.menu -tearoff 0]
-    $om add command -label [trans refresh] \
-      -command "$net TOPIC {[$this name]}"
-    $om add command -label [trans new] -command "getTopic $this"
+    $om add command -label [trans refresh] -command "$net TOPIC {[$this name]}"
+    $om add command -label [trans new] -command "getTopic $this" -state disabled
     $om add separator
     foreach nn [$this topics] {
 	$om add command -label [prune $nn 15] \
-	  -command "$this configure -topic [list $nn]"
+	  -command "$this configure -topic [list $nn]" -state disabled
     }
     emacsTEntry $w.topic.entry
     bind $w.topic.entry <Escape> "notIdle %W $net ; $this makePalette Topic"
     bind $w.topic.entry <ButtonPress-3> "notIdle %W $net ; $this popPalette Topic %X %Y"
-    $w.topic.entry configure -state disabled -width 0
+    $w.topic.entry configure -state disabled -relief sunken -width 0
     grid $w.topic.label
     setProps $this $w.topic.entry
     grid $w.topic.entry -column 1 -row 0 -sticky ew
@@ -1238,7 +1242,9 @@ proc channel_leave {this} {
 proc channel_doAddText {this tag text} {
     upvar #0 $this cdata
     switch {} [set name [$this text]] return
-    $name configure -state normal
+    if {[catch {$name configure -state normal}]} {
+	return
+    }
     if {$cdata(stampMsg)} {
 	set time [clock format [clock seconds] -format $cdata(timeformat)]
 	$name insert end $time
@@ -1363,13 +1369,12 @@ proc channel_unmarkV {this usr} { $this Vmarker $usr {} 0 }
 proc channel_topicState {this state} {
     switch {} [set win [$this window]] return
     if {![winfo exists $win.topic]} return
-    $win.topic.label configure -state $state
-    $win.topic.entry configure -state $state
-    switch $state disabled {
-	$win.topic.entry configure -relief sunken
-    } normal {
-	$win.topic.entry configure -relief raised
+    set ix [$win.topic.label.menu index end]
+    $win.topic.label.menu entryconfigure 1 -state $state
+    for {set i 3} {$i <= $ix} {incr i} {
+        $win.topic.label.menu entryconfigure $i -state $state
     }
+    $win.topic.entry configure -state $state -relief [expr {($state == "disabled") ? "sunken" : "raised"}]
 }
 #
 proc channel_flag {this state} {
