@@ -1,12 +1,12 @@
 #
-# $Source: /home/nlfm/Zircon/lib/RCS/Classes.tcl,v $
-# $Date: 1999/05/17 09:18:25 $
-# $Revision: 1.18.1.98 $
+# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Classes.tcl,v $
+# $Date: 2000/03/30 13:14:50 $
+# $Revision: 1.18.1.102 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
 # ----------------------------------------------------------------------
-# Copyright 1995 The University of Newcastle upon Tyne (see COPYRIGHT)
+# Copyright 1993-2000 The University of Newcastle upon Tyne (see COPYRIGHT)
 # ======================================================================
 #
 package provide zircon 1.18
@@ -224,6 +224,12 @@ class Net "
     players	{}	{list}
     setcolour	red	{}
     foreground	$zircon(fg)	{colour}
+    activefg	red	{colour}
+    activebg	$zircon(bg)	{colour}
+    passivefg	$zircon(fg)	{colour}
+    passivebg	$zircon(bg)	{colour}
+    balloonfg	black	{colour}
+    balloonbg	yellow	{colour}
     myaddr	{}	{host}
     myport	{}	{portnumber}
     multion	0	{bool {Multiple Ons}}
@@ -264,6 +270,7 @@ class Net "
     sorted	0	{bool}
     sortNames	1	{bool}
     nocase	0	{bool}
+    integrate	0	{bool}
     listPattern .*	{pattern}
     topicPattern	.*	{pattern}
     friendsStyle	window	{option {window menu}}
@@ -290,6 +297,7 @@ class Net "
     nicksize	9	{int {Max. Nickname Size}}
     dccblock	2048	{int {DCC Blocksize}}
     msgmax	0	{int {Max. No. of Messages}}
+    ctcpmax	1	{int {Max. No. of CTCPs at once}}
     nickactions	{}	{patterns}
     urlcolour	{blue}	{colour}
 " {
