@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Zircon/lib/RCS/List.tcl,v $
-# $Date: 1999/01/11 13:14:49 $
-# $Revision: 1.18.1.14 $
+# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/List.tcl,v $
+# $Date: 2000/02/04 14:49:37 $
+# $Revision: 1.18.1.15 $
 #
 package provide zircon 1.18
 #
@@ -12,7 +12,7 @@ proc showFull {net lst w x y yl} {
     set w [toplevel .@lt$lst -class Zircon]
     wm overrideredirect $w 1
     wm geometry $w +$x+$y
-    grid [label $w.l -text $chan -bg yellow] -ipadx 3 -ipady 3
+    grid [label $w.l -text $chan -fg [$net balloonfg] -bg [$net balloonbg]] -ipadx 3 -ipady 3
     clipboard clear
     clipboard append $chan
 }
