@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/lib/RCS/Net.tcl,v $
-# $Date: 1998/12/21 09:50:40 $
-# $Revision: 1.18.1.163 $
+# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Net.tcl,v $
+# $Date: 2000/03/31 10:41:04 $
+# $Revision: 1.18.1.166 $
 #
 package provide zircon 1.18
 #
@@ -267,8 +267,8 @@ proc net_quit {this} {
 proc net_show {this} {
     upvar #0 $this ndata
     switch {} $ndata(info) {
-	set ndata(info) [Info -net $this]
 	set ndata(control) [Control -net $this]
+	set ndata(info) [Info -net $this]
 	set ndata(listid) [List -net $this]
     }
     $this flagControl disabled
@@ -335,12 +335,16 @@ proc net_startIRC {this srv args} {
 	    }
 	    if {$rtc == 2} {
 	    	$this inform {Connection attempt failed}
-		retitleFrame [MainControl] $this [$this name] 1
-		retitleFrame [MainInfo] [$this info] [$this name] 1
+		retitleFrame [MainControl] $this [$this name] $this 1
+		if {!$ndata(integrate)} {
+		    retitleFrame [MainInfo] [$this info] [$this name] $this 1
+		}
 	    } {
 	    	$this inform {Connection attempt aborted}
-		retitleFrame [MainControl] $this [$this name] 1
-		retitleFrame [MainInfo] [$this info] [$this name] 1
+		retitleFrame [MainControl] $this [$this name] $this 1
+		if {!$ndata(integrate)} {
+		    retitleFrame [MainInfo] [$this info] [$this name] $this 1
+		}
 	    }
 	    switch {} [$srv nextPort] break
 	}
@@ -394,8 +398,10 @@ proc net_afterCon {this sock} {
 	return
     }
     uplevel #0 set connected($this) 1
-    retitleFrame [MainInfo] [$this info] [set msg "[$this name] - [$this host]"] 1
-    retitleFrame [MainControl] $this $msg 1
+    retitleFrame [MainControl] $this [set msg "[$this name] - [$this host]"] $this 1
+    if {!$ndata(integrate)} {
+        retitleFrame [MainInfo] [$this info] $msg $this 1
+    }
     $this configure -startup 1
     if {$DEBUG} { zDBGRet $this }
 }
@@ -739,6 +745,8 @@ proc net_INVITE {this who where} {
     $this q1Send "INVITE $who :$where"
 }
 #
+proc net_JOIN {this chan args} { channelJoin $this $chan $args }
+#
 proc net_KILL {this who why} { $this q1Send "KILL $who :$why" }
 #
 proc net_KICK {this where who args} {
