@@ -1,12 +1,12 @@
 #
-# $Source: /home/nlfm/Zircon/lib/RCS/Netspace.tcl,v $
-# $Date: 1998/12/21 09:50:42 $
-# $Revision: 1.18.1.24 $
+# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Netspace.tcl,v $
+# $Date: 2000/02/02 10:09:12 $
+# $Revision: 1.18.1.26 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
 # ----------------------------------------------------------------------
-# Copyright 1995 The University of Newcastle upon Tyne (see COPYRIGHT)
+# Copyright 2000 The University of Newcastle upon Tyne (see COPYRIGHT)
 # ======================================================================
 #
 package provide zircon 1.18
@@ -53,7 +53,9 @@ It will be loaded under the name \"$nn1\"."]} return
 	$currentNet show
 	if {$show} {
 	    exposeFrame [MainControl] $currentNet
-	    exposeFrame [MainInfo] [$currentNet info]
+	    if {![$currentNet integrate]} {
+	        exposeFrame [MainInfo] [$currentNet info]
+	    }
 	}
 	if {$DEBUG} { zDBGAdd $currentNet }
     }
