@@ -1,12 +1,12 @@
 #
-# $Source: /home/nlfm/Zircon/lib/RCS/Split.tcl,v $
-# $Date: 1998/09/24 11:04:10 $
-# $Revision: 1.18.1.8 $
+# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Split.tcl,v $
+# $Date: 2000/02/02 10:09:12 $
+# $Revision: 1.18.1.11 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
 # ----------------------------------------------------------------------
-# Copyright 1998 The University of Newcastle upon Tyne (see COPYRIGHT)
+# Copyright 2000 The University of Newcastle upon Tyne (see COPYRIGHT)
 # ======================================================================
 #
 #
@@ -53,7 +53,7 @@ proc user_heal {this} {
 	    } default {
 		set Split($sl) $v
 		catch {after cancel $Heal($sl)}
-		set Heal($sl) [after 120000 $net cleanSplit "{$sl}"]
+		set Heal($sl) [after 120000 "catch {$net cleanSplit \"{$sl}\"}"]
 	    }
 	}
     }
