@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Zircon/lib/RCS/Tracing.tcl,v $
-# $Date: 1999/02/23 13:22:50 $
-# $Revision: 1.18.1.38 $
+# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Tracing.tcl,v $
+# $Date: 2000/02/04 14:49:37 $
+# $Revision: 1.18.1.40 $
 #
 #
 package provide Tracing 1.18
@@ -146,8 +146,10 @@ proc net_closeSock {this msg} {
 	    set ndata(closing) [after $ndata(quitwait) "$this doClose $sock"]
 	}
     }
-    retitleFrame [MainInfo] [$this info] [$this name] 1
-    retitleFrame [MainControl] $this [$this name] 1
+    if {!$ndata(integrate)} {
+        retitleFrame [MainInfo] [$this info] [$this name] $this 1
+    }
+    retitleFrame [MainControl] $this [$this name] $this 1
     zDBGRet $this
     [$this listid] release
 }
