@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Zircon/lib/RCS/confChan.tcl,v $
-# $Date: 1998/11/23 10:32:26 $
-# $Revision: 1.18.1.34 $
+# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/confChan.tcl,v $
+# $Date: 2000/01/28 10:29:18 $
+# $Revision: 1.18.1.36 $
 #
 package provide zircon 1.18
 #
@@ -25,13 +25,14 @@ proc selectDefault {net var} {
 #
 proc selChan {net win y} {
     global selID lbdata
-    saveChan $net
     set v [lindex $lbdata($win) [set p [$win nearest $y]]]
     switch {} [set chn [lindex $v 1]] {
         global defChan
 	incr p -1
 	set chn $defChan($net)
     }
+    switch $chn $selID($net) return
+    saveChan $net
     set selID($net) $chn
     setCCB $net $chn
     confSelClear $win $p
@@ -64,28 +65,34 @@ proc changeChan {net win y} {
 proc setCCB {net chan args} {
     upvar #0 Configure.Channel cInfo confB$net confB
     set w .@conf$net.f.chld
-    switch {} $chan { set state disabled } default {
-	upvar #0 new$chan new
+    switch {} $chan {
+        foreach i [winfo children $w.values] { $i.entry conf -state disabled }
+        foreach i [winfo children $w.options] {
+	    catch {$i conf -state disabled}
+        }
+	set state disabled
+    } default {
+	upvar #0 new$chan new $chan cdata
+	set state normal
 	foreach b [lindex $cInfo(msg) 1] {
+	    $w.options.msg$b conf -state normal
 	    set confB($b) [expr {[lsearch $new(msg) $b] < 0}]
 	}
-	foreach x [array names cInfo] {
-	    switch [lindex [lindex $cInfo($x) 0] 0] bool {
-	        $w.options.$x configure -variable new${chan}($x)
-	    } int - file - key {
-	        entrySet $w.values.$x.entry [$chan $x]
+	foreach {x y} [array get cInfo] {
+	    switch -glob -- $y bool* {
+	        $w.options.$x configure -variable new${chan}($x) -state normal
+	    } int* - file* - key* {
+	        $w.values.$x.entry conf -textvariable new${chan}($x) -state normal
 	    }
         }
-        set v $new(icon)
+	set v $new(icon)
         entrySet $w.values.icon1.entry [lindex $v 0]
         entrySet $w.values.icon2.entry [lindex $v 1]
 	set state normal
     }
-    foreach i [winfo children $w.options] {
-	switch $i $w.options.msg {} default {$i conf -state $state}
+    foreach i [winfo children $w.look] {
+	$i conf -state $state
     }
-    foreach i [winfo children $w.values] {catch {$i.entry conf -state $state}}
-    foreach i {fg bg ft} {catch {$w.options.$i conf -state $state}}
 }
 #
 proc CancelCAC {net win posn args} {
@@ -164,6 +171,7 @@ proc confChannels {net win} {
     bind $wincn.l <Control-h> "confDelChan $net %W %y"
     bind $wincn.l <Button-1> "selChan $net %W %y ; break"
     bind $wincn.l <Double-Button-1> "changeChan $net %W %y ; break"
+    bind $wincn.l <Shift-Button-1> "changeChan $net %W %y"
     frame $win.options
     set i 0
     set j 0
@@ -225,8 +233,8 @@ proc confChanFG {net win} {
     upvar #0 new$selID($net) news
     switch {} [set g [tk_chooseColor -parent $win]] {} default {
 	set news(foreground) $g
+        confDirty $net
     }
-    confDirty $net
 }
 #
 proc confChanBG {net win} {
@@ -234,8 +242,8 @@ proc confChanBG {net win} {
     upvar #0 new$selID($net) news
     switch {} [set g [tk_chooseColor -parent $win]] {} default {
 	set news(background) $g
+        confDirty $net
     }
-    confDirty $net
 }
 #
 proc confChanFt {net win} {
@@ -249,8 +257,8 @@ proc confChanFG {net win} {
     upvar #0 new$selID($net) news
     switch {} [set g [tk_chooseColor -parent $win]] {} default {
 	set news(foreground) $g
+        confDirty $net
     }
-    confDirty $net
 }
 #
 proc confChanBG {net win} {
@@ -258,8 +266,8 @@ proc confChanBG {net win} {
     upvar #0 new$selID($net) news
     switch {} [set g [tk_chooseColor -parent $win]] {} default {
 	set news(background) $g
+        confDirty $net
     }
-    confDirty $net
 }
 #
 proc confChanFt {net win} {
