@@ -1,12 +1,12 @@
 #
-# $Source: /home/nlfm/Working/Zircon/lib/RCS/debug.tcl,v $
-# $Date: 1999/07/23 09:17:37 $
-# $Revision: 1.18.1.42 $
+# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/debug.tcl,v $
+# $Date: 2000/02/04 14:49:37 $
+# $Revision: 1.18.1.45 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
 # ----------------------------------------------------------------------
-# Copyright 1995 The University of Newcastle upon Tyne (see COPYRIGHT)
+# Copyright 2000 The University of Newcastle upon Tyne (see COPYRIGHT)
 # ======================================================================
 #
 package provide Debug 1.18
@@ -167,14 +167,14 @@ proc zCtlQuit {} {
 	puts $y "*** Logging stopped [clock format [clock seconds]]"
 	close $y
     }
-    safeunset DBGL zscr
+    safeUnset DBGL zscr
     destroy .@dbgctl
 }
 #
 proc zDBGRet {net} {
     if {[winfo exists .@dbgctl]} {
 	if {[$net active]} { set op host } { set op name }
-	retitleFrame .@dbgctl $net "Trace of [$net $op]" 1
+	retitleFrame .@dbgctl $net "Trace of [$net $op]" $net 1
     }
 }
 #
@@ -231,7 +231,7 @@ proc zDBGControl {} {
     global zscr zircon zlayout
     if {[winfo exists [set ctl .@dbgctl]]} { popup $ctl ; return }
     [MainControl].helpFrm.info.menu entryconfigure end -state normal
-    makeToplevel $ctl "Zircon Debugger" {safeunset zscr} {}
+    makeToplevel $ctl "Zircon Debugger" {safeUnset zscr} {}
     grid columnconfigure $ctl 0 -weight 1 -minsize 100
     set f [frame $ctl.btn]
     evenGrid $f column 0 3
@@ -275,7 +275,7 @@ proc doRDBG {usr net} {
 proc zDBGRemote {net usr} {
     global zscr zircon zlayout rdbg
     if {![winfo exists [set ctl .@dbgrem]]} {
-        makeToplevel $ctl "Zircon Remote Debugger" {safeunset zscr} {}
+        makeToplevel $ctl "Zircon Remote Debugger" {safeUnset zscr} {}
         grid columnconfigure $ctl 0 -weight 1 -minsize 100
         set f [frame $ctl.btn]
         button $f.close -text [trans dismiss] \
