@@ -1,12 +1,12 @@
 #
-# $Source: /home/nlfm/Zircon/lib/RCS/initial.tcl,v $
-# $Date: 1999/01/29 10:45:36 $
-# $Revision: 1.18.1.179 $
+# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/initial.tcl,v $
+# $Date: 2000/02/04 14:49:37 $
+# $Revision: 1.18.1.182 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
 # ----------------------------------------------------------------------
-# Copyright 1995 The University of Newcastle upon Tyne (see COPYRIGHT)
+# Copyright 1993-2000 The University of Newcastle upon Tyne (see COPYRIGHT)
 # ======================================================================
 #
 package provide zircon 1.18
@@ -236,11 +236,12 @@ proc InitLang {args} {
 #
 proc Initialise {} {
     global argv zircon defaults DEBUG currentNet defaultNet inexp1 \
-      inexp2 userFlags zWList zWClose zWInc ztrans 
+      inexp2 userFlags zWList zWClose zWInc ztrans zInfo
 #
     set zWList {}
     set zWClose {}
     set zWInc 30000
+    set zInfo nil
 #
     array set zircon [set zbase {
 	nameCount	0
@@ -271,6 +272,7 @@ Continue?}]} {
     set ih [expr {[image height advert] + 30}]
     toplevel .ad
     set zircon(fg) [[label .ad.f] cget -foreground]
+    set zircon(bg) [.ad.f cget -background]
     destroy .ad.f
     wm overrideredirect .ad 1
     wm geometry .ad ${iw}x${ih}+[expr {($w -$ih) /2}]+[expr {($h - $ih )/2}]
