@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Zircon/lib/RCS/misc.tcl,v $
-# $Date: 1999/05/17 09:34:58 $
-# $Revision: 1.18.1.53 $
+# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/misc.tcl,v $
+# $Date: 1999/11/23 15:41:09 $
+# $Revision: 1.18.1.55 $
 #
 package provide zircon 1.18
 #
@@ -322,7 +322,7 @@ proc irc318 {net prefix param pargs} {
     grid columnconfigure $w.b 0 -weight 1
     grid columnconfigure $w.b 1 -weight 1
     button $w.b.ok -text [trans dismiss] -command "destroy $w"
-    button $w.b.msg -text [trans message] -command "doMsg $net {$who}"
+    button $w.b.msg -text [trans message] -command "doMsg $net [list $who]"
     grid $w.b.ok $w.b.msg -sticky ew
     if {[info exists whois($net,channels)] && \
       ![string match {} $whois($net,channels)]} {
@@ -387,7 +387,9 @@ proc irc315 {net prefix param pargs} {
 #
 proc irc352 {net prefix param pargs} {
     upvar #0 $net ndata
-    set pp [lindex $ndata(whohandler) 0]
+    switch {} [set pp [lindex $ndata(whohandler) 0]] {
+        set pp doWhoLine
+    }
     eval $pp $net [list $pargs] [list $param]
 }
 #
@@ -457,7 +459,7 @@ proc runCmd {net where cmd} {
     if {[catch {open |$cmd r} ip]} {
 	tellError $net Execerr "Error executing \"$cmd\" - $ip"
     } {
-	fileevent $ip readable "execOP $net $where {$cmd} $ip"
+	fileevent $ip readable "execOP $net $where [list $cmd] $ip"
     }
 }
 #
