@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/misc2.tcl,v $
-# $Date: 1999/09/14 09:08:36 $
-# $Revision: 1.18.1.43 $
+# $Date: 1999/10/20 11:59:24 $
+# $Revision: 1.18.1.44 $
 #
 #
 package provide zircon 1.18
@@ -109,7 +109,7 @@ proc ircII_/DCC {net chid arg} {
 	    set gusr [User :: make $net [lindex $arg 1]]
 	    set file [lindex $arg 2]
 	    set i 0
-	    foreach x $DCCList($net) {
+	    foreach l $DCCList($net) {
 		switch [set op [lindex $l 0]] Send continue
 		set usr [lindex $l 1]
 		set addr [lindex $l 2]
