@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Zircon/lib/RCS/saverc.tcl,v $
-# $Date: 1999/06/25 10:58:15 $
-# $Revision: 1.18.1.32 $
+# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/saverc.tcl,v $
+# $Date: 2000/02/04 14:49:38 $
+# $Revision: 1.18.1.33 $
 #
 package provide zircon 1.18
 #
@@ -246,7 +246,11 @@ proc saveLayout {net} {
 	if {$bak} { exec mv $rc.bak $rc }
 	return 0
     }
-    puts $desc "layout default info [ditchSize .@inf]"
+    if {[winfo exists .@inf]} {
+        puts $desc "layout default info [ditchSize .@inf]"
+    } {
+        puts $desc {# we are integrated, so info window}
+    }
     puts $desc "layout default control [ditchSize .@ctl]"
     if {[winfo exists .@dbgctl]} {
 	puts $desc "layout default debug [ditchSize .@dbgctl]"
