@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Zircon/plugins/Dcc/RCS/dcc.tcl,v $
-# $Date: 1998/11/06 10:07:51 $
-# $Revision: 1.18.1.63 $
+# $Source: /home/nlfm/Working/Zircon/Released/plugins/Dcc/RCS/dcc.tcl,v $
+# $Date: 2000/02/06 19:49:46 $
+# $Revision: 1.18.1.64 $
 #
 package provide Dcc 1.18
 #
@@ -114,7 +114,7 @@ proc dccDel {net w id usr} {
 	destroy $w.t$id $w.u$id $w.f$id $w.a$id $w.c$id
 	if {[llength [winfo children $w]] <= 1} {
 	    set z [winfo parent $w]
-	    closeFrame [winfo parent $z] [winfo name $z]
+	    closeFrame [winfo parent $z] [winfo name $z] $net
 	}
 	switch {} $DCCList($net) {destroy [winfo toplevel $w]}
     }
@@ -148,7 +148,7 @@ proc addDCCRequest {net op usr fln addr port leng} {
     grid [button $win.c$ix -text [trans cancel] -command "dccDel $net $win $ix $usr"]\
       -sticky ew -row $rw -column 4
     popup $w
-    openFrame $w s$op
+    openFrame $w s$op $net
     lappend DCCList($net) [list $ix $op $usr $addr $port $fln $leng 0 0]
     $usr ref
     if {[winfo exists .@dls$net]} { buildDCCList $net }
@@ -271,8 +271,8 @@ proc dccClose {net op usr file ix w} {
     buildDCCList $net
 }
 #
-proc doTitle {grd w sub ttl} {
-    if {$grd > 1} { openFrame $w $sub } { closeFrame $w $sub }
+proc doTitle {grd w sub net} {
+    if {$grd > 1} { openFrame $w $sub $net} { closeFrame $w $sub $net}
 }
 #
 proc buildDCCList {net args} {
@@ -307,7 +307,7 @@ proc buildDCCList {net args} {
 	  -column 2 -sticky ew
 	incr grd
     }
-    doTitle $grd $w coff $tls(coff)
+    doTitle $grd $w coff $net
     set w1 $w.achat.bdy
     set grd 1
     foreach nn [$net chats] {
@@ -321,7 +321,7 @@ proc buildDCCList {net args} {
 	    incr grd
 	}
     }
-    doTitle $grd $w achat $tls(achat)
+    doTitle $grd $w achat $net
     foreach arr {Offer Send Get} {
 	set w1 $w.f$arr.bdy
 	grid columnconfigure $w1 1 -weight 1
@@ -339,7 +339,7 @@ proc buildDCCList {net args} {
 		incr grd
 	    }
 	}
-	doTitle $grd $w f$arr $tls(f$arr)
+	doTitle $grd $w f$arr $net
     }
 }
 #
